function [l1,v1,ammv,x1]=jacobi6(x,R,tol)
% La funzione realizza il ciclo interno dello schema di soluzione del problema a 6 
% equazioni basandosi su un metodo iterativo per la soluzione di sistemi lineari e 
% prendendo spunto  in particolare dal metodo di Jacobi. Riceve come parametri d'ingresso un valore iniziale
% di X (numero di moli totali di ammoniaca che si suppone siano presenti in condizioni 
% di equilibrio), una matrice di permutazione delle righe R ed una tolleranza. La funzione 
% restituisce il numero di moli totali presenti nelle due fasi, il numero di moli di 
% ammoniaca in fase vapore ed il vettore x1 delle quantit molari di ciascuna specie 
% chimica.

l=5;
v=9-x-l;
A6=matrix6(l,v);
b6=vect6(x);
x0=A6\b6;
% Si inizializzano i valori di X, l, v, la matrice del sistema ed il vettore dei 
% termini noti. Viene calcolata una prima soluzione x0, punto di partenza.
l0=x0(1)+x0(3);
v0=x0(2)+x0(4)+x0(5)+x0(6);
A6=matrix6(l0,v0);
% Vengono aggiornati i valori di l e v e quindi la matrice.
N=diag(diag(R*(A6)));
b6=R*b6;
P=N-(R*A6);
% La matrice A6 del sistema (e di conseguenza anche il vettore dei termini noti b6) 
% subisce una permutazione delle righe in modo da poter essere decomposta secondo 
% il metodo di Jacobi. Si ottiene una matrice N diagonale, facilmente invertibile,
% ed una matrice P.
iN=inv(N);
M=iN*P;
d=iN*b6;
% Si calcolano la matrice M di iterazione ed il nuovo termine noto.
x1=M*x0+d;
l1=x1(1)+x1(3);
v1=x1(2)+x1(4)+x1(5)+x1(6);
ammv=x1(4);  % Si isola il numero di moli di ammoniaca in fase vapore
% Il metodo iterativo viene avviato e di conseguenza i termini che interessano per il
% proseguimento della risoluzione vengono aggiornati.
count=1;
ro(count)=norm(max(eig(M)));
% Viene registrato nel vettore ro il raggio spettrale della matrice di iterazione M; 
devx=norm(x1-x0)/norm(x0);
% Lo scarto relativo tra due soluzioni successive x0 e x1  utilizzato come criterio 
% per la tolleranza.

while devx>=tol   %Test di tolleranza.
   x0=x1;
   l0=l1;
   v0=v1;
   A6=matrix6(l0,v0);
   N=diag(diag(R*(A6)));
   P=N-(R*A6);
   iN=inv(N);
   M=iN*P;
   d=iN*b6;
   % Aggiornamento dei punti di partenza, delle matrici di iterazione e dei vettori 
   % dei termini noti
   x1=M*x0+d;
   l1=x1(1)+x1(3);
   v1=x1(2)+x1(4)+x1(5)+x1(6);
   ammv=x1(4);
   count=count+1;
   ro(count)=norm(max(eig(M)));
   devx=norm(x1-x0)/norm(x0);
end
disp(x1);
disp(ro');
% Vengono visualizzati i vettori x1 (numero di moli delle singole componenti il sistema)
% e ro (che contiene i raggi spettrali delle matrici di iterazione di ciascun passo).